You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@airavata.apache.org by ma...@apache.org on 2019/06/03 16:39:29 UTC

[airavata] branch develop updated: AIRAVATA-3047 Distinguish between enabled and email verified

This is an automated email from the ASF dual-hosted git repository.

machristie pushed a commit to branch develop
in repository https://gitbox.apache.org/repos/asf/airavata.git


The following commit(s) were added to refs/heads/develop by this push:
     new f3ec141  AIRAVATA-3047 Distinguish between enabled and email verified
f3ec141 is described below

commit f3ec14118bc78671387f404d8de0b3bb06cd290b
Author: Marcus Christie <ma...@apache.org>
AuthorDate: Mon Jun 3 12:39:19 2019 -0400

    AIRAVATA-3047 Distinguish between enabled and email verified
---
 .../iam/admin/services/core/impl/TenantManagementKeycloakImpl.java    | 4 +++-
 1 file changed, 3 insertions(+), 1 deletion(-)

diff --git a/airavata-services/profile-service/iam-admin-services-core/src/main/java/org/apache/airavata/service/profile/iam/admin/services/core/impl/TenantManagementKeycloakImpl.java b/airavata-services/profile-service/iam-admin-services-core/src/main/java/org/apache/airavata/service/profile/iam/admin/services/core/impl/TenantManagementKeycloakImpl.java
index 1b49f1d..221d5f9 100644
--- a/airavata-services/profile-service/iam-admin-services-core/src/main/java/org/apache/airavata/service/profile/iam/admin/services/core/impl/TenantManagementKeycloakImpl.java
+++ b/airavata-services/profile-service/iam-admin-services-core/src/main/java/org/apache/airavata/service/profile/iam/admin/services/core/impl/TenantManagementKeycloakImpl.java
@@ -782,8 +782,10 @@ public class TenantManagementKeycloakImpl implements TenantManagementInterface {
         // Just default these. UserProfile isn't a great data model for this data since it isn't actually the Airavata UserProfile
         profile.setLastAccessTime(0);
         profile.setValidUntil(0);
         // Use state field to indicate whether user has been enabled in Keycloak
         if (userRepresentation.isEnabled()) {
+            profile.setState(Status.ACTIVE);
+        } else if (userRepresentation.isEmailVerified()) {
             profile.setState(Status.CONFIRMED);
         } else {
             profile.setState(Status.PENDING_CONFIRMATION);
@@ -782,8 +782,10 @@ public class TenantManagementKeycloakImpl implements TenantManagementInterface {
         profile.setLastAccessTime(0);
         profile.setValidUntil(0);
-        // Use state field to indicate whether user has been enabled in Keycloak
+        // Use state field to indicate whether user has been enabled or email verified in Keycloak
         if (userRepresentation.isEnabled()) {